/**
 * Converts a standard &lt;select&gt; field into a component picker
 *
 * HTML:
 *
 * <select size="5" name="components" multiple="multiple" id="components">
 *   <optgroup label="Unreleased Versions">
 *       <option value="Harwood">Scott Harwood</option>
 *       <option value="Hughes">Scott Hughes</option>
 *       <option value="Farquar">Scott Farquar</option>
 *   </optgroup>
 * </select>
 *
 * JavaScript:
 *
 * jira.app.findComponentSelectAndConvertToPicker(document.body, "#components")
 *
 * @namespace jira.app
 */
jira.app.findComponentSelectAndConvertToPicker = function () {

    function createPicker($selectField) {
        new AJS.MultiSelect({
           element: $selectField,
           itemAttrDisplayed: "label",
           errorMessage: AJS.params.multiselectComponentsError
        });
    };

    function locateSelect(parent) {

        var $parent = AJS.$(parent),
            $selectField;

        if ($parent.is("select")) {
            $selectField = $parent;
        } else {
            $selectField = $parent.find("select");
        }

        return $selectField;
    }

    var DEFAULT_SELECTORS = [
        "div.aui-field-componentspicker.frother-control-renderer", // aui forms
        "td.aui-field-componentspicker.frother-control-renderer", // convert to subtask and move
        "tr.aui-field-componentspicker.frother-control-renderer" // bulk edit
    ];

    return function (context, selector) {

        selector = selector || DEFAULT_SELECTORS.join(", ");

        AJS.$(selector, context).each(function () {

            
            var $selectField = locateSelect(this);

            if ($selectField.length) {
                createPicker($selectField);
            } else {
                /* [logging] */
                AJS.log("jira.app.convertToComponentPicker: Tried to create version picker using [" + selector + "] "
                        + "however selector does not match or could not find <select>");
                /* [logging] end */
            }
        });
    };
    
}();
