/**
 * Contains code related to issue operations in JIRA
 *
 * @namespace jira.app.issueoperations
 * @since 4.2
 * @module issueoperations
 * @class issue
 * @requires AJS.$

 */

(function ($)
{
    $.namespace('jira.app.issueoperations');

    /**
     * This will add a click vent to the the assigned to me link of the assignee field so that it selects
     *  the current user in the assignee select box
     *
     * @param {jQuery, HTMLElement} context - the context used for selection
     */
    jira.app.issueoperations.wireAssignToMeLink = function(context) {
        jQuery('#assign-to-me-trigger', context).click(function (e) {
            e.preventDefault();
            var assigneeId = getHashedLinkTarget(jQuery(this).attr('href'));
            var currentUserOption = jQuery(assigneeId, context).find('.current-user');
            var val = currentUserOption.val();
            jQuery(assigneeId, context).val(val).change(); // cause a change event as well as set it
        });
    };

    /**
     * On IE7 it takes a href like '#assignee' and returns http:/x.x.x./x/x#assignee.  Why. why
     */
    function getHashedLinkTarget(url) {
        var hashIndex = url.indexOf('#');
        if (hashIndex != -1) {
            return url.substring(hashIndex);
        } else {
            return url;
        }
    }


})(AJS.$);

// on load we want to wire this up
AJS.$(function () {
    jira.app.issueoperations.wireAssignToMeLink(document);
});

